<?php
/*
Plugin Name: Comment URL Control
Plugin URI: http://www.weinschenker.name/comment_url_control
Description: This plugin lets you control, if commenters urls should be shown.
Version:  0.5
Author: Jan Weinschenker
Author URI: http://www.weinschenker.name

   
    Plugin: Copyright 2007  Jan Weinschenker  (email: kontakt@weinschenker.name)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

register_activation_hook(__FILE__,'curlc_install');
add_option('comment_url_control_settings', $data, 'Comment-URL Control');
add_action('admin_menu', 'curlc_register_with_options');


/**
 * Create datbase table
 */
function curlc_install(){
	global $wpdb;
	$table_name = $wpdb->prefix . "curlc_show_comment_url";
	if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
	$sql = "CREATE TABLE " . $table_name . " (
	  comment_id bigint(20) NOT NULL,
	  show_url bool NOT NULL,
	  UNIQUE KEY (comment_id)
	);";
	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);
    }
}

/**
 * Register with options-page
 */
function curlc_register_with_options() {
	if (function_exists('add_options_page')) {
		add_options_page('Comment-URL Control', 'Comment-URL Control', 8, basename(__FILE__), 'curlc_options_subpanel');
	}
}


/**
 * Display the plugin's option-page
 */
function curlc_options_subpanel() {
    global $_POST;
	/* This array contains all settings for this plugin. */
	$data = array (
		'curlc-use-nofollow' => '',
        'curlc-default-url' => ''
	);
	/* Get settings from database via WordPress framework */
	$comment_url_control_settings = get_option('comment_url_control_settings');
	$comment_url_keywords_flash = "";

	if (curlc_user_is_authorized()) {
		if (isset ($_POST['curlc-use-nofollow']) or isset ($_POST['curlc-default-url'])) {
			$comment_url_control_settings['curlc-use-nofollow'] = $_POST['curlc-use-nofollow'];
			$comment_url_control_settings['curlc-default-url'] = $_POST['curlc-default-url'];
			update_option('comment_url_control_settings', $comment_url_control_settings);
			$comment_url_keywords_flash = "Your settings have been saved.";
		}

	} else {
		$comment_url_keywords_flash = "You don't have enough access rights.";
	}

	if ($comment_url_keywords_flash != '') { ?>
		<div id="message"class="updated fade"><p><?php echo $comment_url_keywords_flash ?></p></div>
    <?php } ?>

	<div class="wrap">
	<h2>Comment URL Control</h2>
    	<form action="" method="post">
            <input type="hidden" name="redirect" value="true" />
            <p>Here you can enter the URI that will be used instead of the commenter's own URI. You can also specify, if the nofollow-attribute should be used for the URI.</p>
            <p></p>
			<p><label for="curlc-default-url"><strong>Use this <abbr title="Uniform Ressource Identifier">URI</abbr> instead of the commenter's URI (you can also leave it blank)</strong></label><br /><input type="text" id="curlc-default-url" name="curlc-default-url" value="<?php echo htmlentities($comment_url_control_settings['curlc-default-url']); ?>" size="80" /></p>
            <p><label for="curlc-use-nofollow"><strong>Usage of rel=&quot;nofollow&quot;</strong> (I recommend <a href="http://www.itst.org/nonofollow/">not using it</a>)</label><br /><select id="curlc-use-nofollow" name="curlc-use-nofollow" size="1">
            <?php
            $use_nofollow=false; 
            if ($comment_url_control_settings['curlc-use-nofollow'] == "true"){
                $use_nofollow=true;
            } else {
                $use_nofollow=false;
            }
            ?>
                <option value="false" <?php if  (!$use_nofollow) { ?> selected="selected" <?php }?>>no (recommended)</option>
                <option value="true"  <?php if  ($use_nofollow)  { ?> selected="selected" <?php }?>>yes</option>
            </select></p>
            <p><input type="submit" value="Save" /></p>
        </form>
    <h2>Documentation and Support for this Plugin</h2>
    <p>Can be found at the <a href="http://www.weinschenker.name/comment-url-control/" title="go to http://www.weinschenker.name/comment-url-control/">Plugin-Homepage</a>.</p>
    </div>
<?php
}

/**
 * Check if the current user is allowed to activate plugins.
 */
function curlc_user_is_authorized() {
	global $user_level;
	if (function_exists("current_user_can")) {
		return current_user_can('activate_plugins');
	} else {
		return $user_level > 5;
	}
}

/**
 * Returns whether the comment is switched or not
 */
function curlc_switch_url(){
    global $wpdb;
    global $comment;
    $commentID = $comment->comment_ID;
    $table_name = $wpdb->prefix . "curlc_show_comment_url";
    $query = "SELECT show_url FROM " . $table_name . " WHERE comment_id=$commentID LIMIT 1";
    $result = mysql_query($query);
    $num_rows = mysql_num_rows($result);
    if ($num_rows==0){
        return false;
    } else {
        return true;
    }
}

/**
 * Substitute for WordPress's comment_author_link()
 * Displays the switched Link for switched comments or the author's Link for
 * non-switched comments.
 */
function curlc_comment_author_link(){
    global $comment;
    $settings = get_option('comment_url_control_settings');
    $default_url = $settings['curlc-default-url'];
    $use_nofollow = $settings['curlc-use-nofollow'];

    if (curlc_switch_url() && $default_url != ""){
        ?><a href="<?php echo $default_url; ?>" <?php if ($use_nofollow=="true"){?> rel="nofollow" <?php } ?>> <?php echo $comment->comment_author;?></a><?php
    } else if (curlc_switch_url() && $default_url == ""){
        echo $comment->comment_author;
    } else {
        comment_author_link();
    }
}

/**
 * Substitute for WordPress's comment_author_url()
 * Displays the switched URL for switched comments or the author's URL for
 * non-switched comments.
 */
function curlc_comment_author_url(){
    global $comment;
    $settings = get_option('comment_url_control_settings');
    $default_url = $settings['curlc-default-url'];
    if (curlc_switch_url()){
        echo $default_url;
    } else {
        comment_author_url();
    }
}


/**
 * Displays the Swwitch-button inside the comment. Renders a complete HTML-form. 
 * Only visible to a logged-in admin-user with user-level==10
 */
function curlc_switch_button(){
    get_currentuserinfo() ;
    global $user_level;
    if (is_user_logged_in() and $user_level==10) {
        global $post;
        global $comment;
        ?>
        <form action="<?php echo $blogUrl;?>/wp-content/plugins/comment_url_post.php" method="post">
        <input type="hidden" name="comment" value="<?php echo $comment->comment_ID; ?>" />
        <input type="hidden" name="post" value="<?php echo $post->ID; ?>" />
        <input type="submit" name="curlc_send" value="switch author-URI" title="switch the URI of this comment's author">
        </form>
        <?php
    }
}
?>